@@ -47,7 +47,7 @@ FF_MAYBE_UNUSED static bool detectArmbianVersion(FFOSResult* result)
     // - `Armbian_Security` for images with kali repo added
     // - `Armbian-unofficial` for an unofficial image built from source, e.g. during development and testing
     if (ffStrbufStartsWithS(&result->prettyName, "Armbian"))
-        ffStrbufSetS(&result->name, "Armbian");
+        ffStrbufSetStatic(&result->name, "Armbian");
     else
         return false;
     ffStrbufSet(&result->idLike, &result->id);
@@ -69,113 +69,119 @@ FF_MAYBE_UNUSED static void getUbuntuFlavour(FFOSResult* result)
         return;
     else if(ffStrbufStartsWithS(&result->prettyName, "Linux Lite "))
     {
-        ffStrbufSetS(&result->name, "Linux Lite");
-        ffStrbufSetS(&result->id, "linuxlite");
-        ffStrbufSetS(&result->idLike, "ubuntu");
+        ffStrbufSetStatic(&result->name, "Linux Lite");
+        ffStrbufSetStatic(&result->id, "linuxlite");
+        ffStrbufSetStatic(&result->idLike, "ubuntu");
         ffStrbufSetS(&result->versionID, result->prettyName.chars + strlen("Linux Lite "));
         return;
     }
     else if(ffStrbufStartsWithS(&result->prettyName, "Rhino Linux "))
     {
-        ffStrbufSetS(&result->name, "Rhino Linux");
-        ffStrbufSetS(&result->id, "rhinolinux");
-        ffStrbufSetS(&result->idLike, "ubuntu");
+        ffStrbufSetStatic(&result->name, "Rhino Linux");
+        ffStrbufSetStatic(&result->id, "rhinolinux");
+        ffStrbufSetStatic(&result->idLike, "ubuntu");
         ffStrbufSetS(&result->versionID, result->prettyName.chars + strlen("Rhino Linux "));
         return;
     }
     else if(ffStrbufStartsWithS(&result->prettyName, "VanillaOS "))
     {
-        ffStrbufSetS(&result->id, "vanilla");
-        ffStrbufSetS(&result->idLike, "ubuntu");
+        ffStrbufSetStatic(&result->id, "vanilla");
+        ffStrbufSetStatic(&result->idLike, "ubuntu");
+    }
+
+    if (ffPathExists("/usr/bin/lliurex-version", FF_PATHTYPE_FILE))
+    {
+        ffStrbufSetStatic(&result->name, "LliureX");
+        ffStrbufSetStatic(&result->id, "lliurex");
+        ffStrbufClear(&result->version);
+        if (ffProcessAppendStdOut(&result->version, (char* const[]) {
+            "/usr/bin/lliurex-version",
+            NULL,
+        }) == NULL) // 8.2.2
+            ffStrbufTrimRightSpace(&result->version);
+        ffStrbufSetF(&result->prettyName, "LliureX %s", result->version.chars);
+        ffStrbufSetStatic(&result->idLike, "ubuntu");
+        return;
     }
 
     if(ffStrContains(xdgConfigDirs, "kde") || ffStrContains(xdgConfigDirs, "plasma") || ffStrContains(xdgConfigDirs, "kubuntu"))
     {
-        ffStrbufSetS(&result->name, "Kubuntu");
-        ffStrbufSetS(&result->prettyName, "Kubuntu");
-        ffStrbufSetS(&result->id, "kubuntu");
-        ffStrbufSetS(&result->idLike, "ubuntu");
+        ffStrbufSetStatic(&result->name, "Kubuntu");
+        ffStrbufSetF(&result->prettyName, "Kubuntu %s", result->version.chars);
+        ffStrbufSetStatic(&result->id, "kubuntu");
+        ffStrbufSetStatic(&result->idLike, "ubuntu");
         return;
     }
 
     if(ffStrContains(xdgConfigDirs, "xfce") || ffStrContains(xdgConfigDirs, "xubuntu"))
     {
-        ffStrbufSetS(&result->name, "Xubuntu");
-        ffStrbufSetS(&result->prettyName, "Xubuntu");
-        ffStrbufSetS(&result->id, "xubuntu");
-        ffStrbufSetS(&result->idLike, "ubuntu");
+        ffStrbufSetStatic(&result->name, "Xubuntu");
+        ffStrbufSetF(&result->prettyName, "Xubuntu %s", result->version.chars);
+        ffStrbufSetStatic(&result->id, "xubuntu");
+        ffStrbufSetStatic(&result->idLike, "ubuntu");
         return;
     }
 
     if(ffStrContains(xdgConfigDirs, "lxqt") || ffStrContains(xdgConfigDirs, "lubuntu"))
     {
-        ffStrbufSetS(&result->name, "Lubuntu");
-        ffStrbufSetS(&result->prettyName, "Lubuntu");
-        ffStrbufSetS(&result->id, "lubuntu");
-        ffStrbufSetS(&result->idLike, "ubuntu");
+        ffStrbufSetStatic(&result->name, "Lubuntu");
+        ffStrbufSetF(&result->prettyName, "Lubuntu %s", result->version.chars);
+        ffStrbufSetStatic(&result->id, "lubuntu");
+        ffStrbufSetStatic(&result->idLike, "ubuntu");
         return;
     }
 
     if(ffStrContains(xdgConfigDirs, "budgie"))
     {
-        ffStrbufSetS(&result->name, "Ubuntu Budgie");
-        ffStrbufSetS(&result->prettyName, "Ubuntu Budgie");
-        ffStrbufSetS(&result->id, "ubuntu-budgie");
-        ffStrbufSetS(&result->idLike, "ubuntu");
+        ffStrbufSetStatic(&result->name, "Ubuntu Budgie");
+        ffStrbufSetF(&result->prettyName, "Ubuntu Budgie %s", result->version.chars);
+        ffStrbufSetStatic(&result->id, "ubuntu-budgie");
+        ffStrbufSetStatic(&result->idLike, "ubuntu");
         return;
     }
 
     if(ffStrContains(xdgConfigDirs, "cinnamon"))
     {
-        ffStrbufSetS(&result->name, "Ubuntu Cinnamon");
-        ffStrbufSetS(&result->prettyName, "Ubuntu Cinnamon");
-        ffStrbufSetS(&result->id, "ubuntu-cinnamon");
-        ffStrbufSetS(&result->idLike, "ubuntu");
+        ffStrbufSetStatic(&result->name, "Ubuntu Cinnamon");
+        ffStrbufSetF(&result->prettyName, "Ubuntu Cinnamon %s", result->version.chars);
+        ffStrbufSetStatic(&result->id, "ubuntu-cinnamon");
+        ffStrbufSetStatic(&result->idLike, "ubuntu");
         return;
     }
 
     if(ffStrContains(xdgConfigDirs, "mate"))
     {
-        ffStrbufSetS(&result->name, "Ubuntu MATE");
-        ffStrbufSetS(&result->prettyName, "Ubuntu MATE");
-        ffStrbufSetS(&result->id, "ubuntu-mate");
-        ffStrbufSetS(&result->idLike, "ubuntu");
+        ffStrbufSetStatic(&result->name, "Ubuntu MATE");
+        ffStrbufSetF(&result->prettyName, "Ubuntu MATE %s", result->version.chars);
+        ffStrbufSetStatic(&result->id, "ubuntu-mate");
+        ffStrbufSetStatic(&result->idLike, "ubuntu");
         return;
     }
 
     if(ffStrContains(xdgConfigDirs, "studio"))
     {
-        ffStrbufSetS(&result->name, "Ubuntu Studio");
-        ffStrbufSetS(&result->prettyName, "Ubuntu Studio");
-        ffStrbufSetS(&result->id, "ubuntu-studio");
-        ffStrbufSetS(&result->idLike, "ubuntu");
+        ffStrbufSetStatic(&result->name, "Ubuntu Studio");
+        ffStrbufSetF(&result->prettyName, "Ubuntu Studio %s", result->version.chars);
+        ffStrbufSetStatic(&result->id, "ubuntu-studio");
+        ffStrbufSetStatic(&result->idLike, "ubuntu");
         return;
     }
 
     if(ffStrContains(xdgConfigDirs, "sway"))
     {
-        ffStrbufSetS(&result->name, "Ubuntu Sway");
-        ffStrbufSetS(&result->prettyName, "Ubuntu Sway");
-        ffStrbufSetS(&result->id, "ubuntu-sway");
-        ffStrbufSetS(&result->idLike, "ubuntu");
+        ffStrbufSetStatic(&result->name, "Ubuntu Sway");
+        ffStrbufSetF(&result->prettyName, "Ubuntu Sway %s", result->version.chars);
+        ffStrbufSetStatic(&result->id, "ubuntu-sway");
+        ffStrbufSetStatic(&result->idLike, "ubuntu");
         return;
     }
 
     if(ffStrContains(xdgConfigDirs, "touch"))
     {
-        ffStrbufSetS(&result->name, "Ubuntu Touch");
-        ffStrbufSetS(&result->prettyName, "Ubuntu Touch");
-        ffStrbufSetS(&result->id, "ubuntu-touch");
-        ffStrbufSetS(&result->idLike, "ubuntu");
-        return;
-    }
-
-    if(ffStrContains(xdgConfigDirs, "lliurex"))
-    {
-        ffStrbufSetS(&result->name, "LliureX");
-        ffStrbufSetS(&result->prettyName, "LliureX");
-        ffStrbufSetS(&result->id, "lliurex");
-        ffStrbufSetS(&result->idLike, "ubuntu");
+        ffStrbufSetStatic(&result->name, "Ubuntu Touch");
+        ffStrbufSetF(&result->prettyName, "Ubuntu Touch %s", result->version.chars);
+        ffStrbufSetStatic(&result->id, "ubuntu-touch");
+        ffStrbufSetStatic(&result->idLike, "ubuntu");
         return;
     }
 }
@@ -196,8 +202,8 @@ FF_MAYBE_UNUSED static bool detectDebianDerived(FFOSResult* result)
         return true;
     else if (ffStrbufStartsWithS(&result->name, "Loc-OS"))
     {
-        ffStrbufSetS(&result->id, "locos");
-        ffStrbufSetS(&result->idLike, "debian");
+        ffStrbufSetStatic(&result->id, "locos");
+        ffStrbufSetStatic(&result->idLike, "debian");
         return true;
     }
     else if (ffStrbufEqualS(&result->name, "Parrot Security"))
@@ -210,15 +216,15 @@ FF_MAYBE_UNUSED static bool detectDebianDerived(FFOSResult* result)
     else if (ffStrbufStartsWithS(&result->name, "Lilidog GNU/Linux"))
     {
         // https://github.com/fastfetch-cli/fastfetch/issues/1373
-        ffStrbufSetS(&result->id, "lilidog");
-        ffStrbufSetS(&result->idLike, "debian");
+        ffStrbufSetStatic(&result->id, "lilidog");
+        ffStrbufSetStatic(&result->idLike, "debian");
         return true;
     }
     else if (access("/usr/bin/pveversion", X_OK) == 0)
     {
-        ffStrbufSetS(&result->id, "pve");
-        ffStrbufSetS(&result->idLike, "debian");
-        ffStrbufSetS(&result->name, "Proxmox VE");
+        ffStrbufSetStatic(&result->id, "pve");
+        ffStrbufSetStatic(&result->idLike, "debian");
+        ffStrbufSetStatic(&result->name, "Proxmox VE");
         ffStrbufClear(&result->versionID);
         if (ffProcessAppendStdOut(&result->versionID, (char* const[]) {
             "/usr/bin/dpkg-query",
@@ -231,22 +237,39 @@ FF_MAYBE_UNUSED static bool detectDebianDerived(FFOSResult* result)
         ffStrbufSetF(&result->prettyName, "Proxmox VE %s", result->versionID.chars);
         return true;
     }
-    else if (ffStrbufContainS(&instance.state.platform.sysinfo.release, "+rpt-rpi-"))
+    else if (ffPathExists("/etc/rpi-issue", FF_PATHTYPE_FILE))
     {
         // Raspberry Pi OS
-        ffStrbufSetS(&result->id, "raspbian");
-        ffStrbufSetS(&result->idLike, "debian");
-        ffStrbufSetS(&result->name, "Raspberry Pi OS");
-        ffStrbufSetS(&result->prettyName, "Raspberry Pi OS");
+        ffStrbufSetStatic(&result->id, "raspbian");
+        ffStrbufSetStatic(&result->idLike, "debian");
+        ffStrbufSetStatic(&result->name, "Raspberry Pi OS");
+        ffStrbufSetStatic(&result->prettyName, "Raspberry Pi OS");
+        return true;
+    }
+    else if (ffPathExists("/boot/dietpi/.version", FF_PATHTYPE_FILE))
+    {
+        // DietPi
+        ffStrbufSetStatic(&result->id, "dietpi");
+        ffStrbufSetStatic(&result->name, "DietPi");
+        ffStrbufSetStatic(&result->prettyName, "DietPi");
+        ffStrbufSetStatic(&result->idLike, "debian");
+        FF_STRBUF_AUTO_DESTROY core = ffStrbufCreate();
+        FF_STRBUF_AUTO_DESTROY sub = ffStrbufCreate();
+        FF_STRBUF_AUTO_DESTROY rc = ffStrbufCreate();
+        if (ffParsePropFileValues("/boot/dietpi/.version", 3, (FFpropquery[]) {
+            {"G_DIETPI_VERSION_CORE=", &core},
+            {"G_DIETPI_VERSION_SUB=", &sub},
+            {"G_DIETPI_VERSION_RC=", &rc},
+        })) ffStrbufAppendF(&result->prettyName, " %s.%s.%s", core.chars, sub.chars, rc.chars);
         return true;
     }
     else if (ffStrbufEndsWithS(&instance.state.platform.sysinfo.release, "+truenas"))
     {
         // TrueNAS Scale
-        ffStrbufSetS(&result->id, "truenas-scale");
-        ffStrbufSetS(&result->idLike, "debian");
-        ffStrbufSetS(&result->name, "TrueNAS Scale");
-        ffStrbufSetS(&result->prettyName, "TrueNAS Scale");
+        ffStrbufSetStatic(&result->id, "truenas-scale");
+        ffStrbufSetStatic(&result->idLike, "debian");
+        ffStrbufSetStatic(&result->name, "TrueNAS Scale");
+        ffStrbufSetStatic(&result->prettyName, "TrueNAS Scale");
         return true;
     }
     else
@@ -255,9 +278,9 @@ FF_MAYBE_UNUSED static bool detectDebianDerived(FFOSResult* result)
         FF_STRBUF_AUTO_DESTROY lsbRelease = ffStrbufCreate();
         if (ffAppendFileBuffer("/etc/lsb-release", &lsbRelease) && ffStrbufContainS(&lsbRelease, "DISTRIB_ID=MX"))
         {
-            ffStrbufSetS(&result->id, "mx");
-            ffStrbufSetS(&result->idLike, "debian");
-            ffStrbufSetS(&result->name, "MX");
+            ffStrbufSetStatic(&result->id, "mx");
+            ffStrbufSetStatic(&result->idLike, "debian");
+            ffStrbufSetStatic(&result->name, "MX");
 
             ffStrbufClear(&result->version);
             ffParsePropLines(lsbRelease.chars, "DISTRIB_RELEASE=", &result->version);
@@ -274,16 +297,25 @@ FF_MAYBE_UNUSED static bool detectDebianDerived(FFOSResult* result)
     return false;
 }
 
-static void detectOS(FFOSResult* os)
+FF_MAYBE_UNUSED static bool detectFedoraVariant(FFOSResult* result)
 {
-    #ifdef FF_CUSTOM_OS_RELEASE_PATH
-    parseOsRelease(FF_STR(FF_CUSTOM_OS_RELEASE_PATH), os);
-        #ifdef FF_CUSTOM_LSB_RELEASE_PATH
-        parseLsbRelease(FF_STR(FF_CUSTOM_LSB_RELEASE_PATH), os);
-        #endif
-    return;
-    #endif
+    if (ffStrbufEqualS(&result->variantID, "coreos")
+        || ffStrbufEqualS(&result->variantID, "kinoite")
+        || ffStrbufEqualS(&result->variantID, "sericea")
+        || ffStrbufEqualS(&result->variantID, "silverblue"))
+    {
+        ffStrbufAppendC(&result->id, '-');
+        ffStrbufAppend(&result->id, &result->variantID);
+        ffStrbufSetStatic(&result->idLike, "fedora");
+        return true;
+    }
+    return false;
+}
 
+static bool detectBedrock(FFOSResult* os)
+{
+    const char* bedrockRestrict = getenv("BEDROCK_RESTRICT");
+    if(bedrockRestrict && bedrockRestrict[0] == '1') return false;
     if(parseOsRelease(FASTFETCH_TARGET_DIR_ROOT "/bedrock" FASTFETCH_TARGET_DIR_ETC "/bedrock-release", os))
     {
         if(os->id.length == 0)
@@ -296,8 +328,23 @@ static void detectOS(FFOSResult* os)
             ffStrbufAppendS(&os->prettyName, "Bedrock Linux");
 
         parseOsRelease("/bedrock" FASTFETCH_TARGET_DIR_ETC "/os-release", os);
-        return;
+        return true;
     }
+    return false;
+}
+
+static void detectOS(FFOSResult* os)
+{
+    #ifdef FF_CUSTOM_OS_RELEASE_PATH
+    parseOsRelease(FF_STR(FF_CUSTOM_OS_RELEASE_PATH), os);
+        #ifdef FF_CUSTOM_LSB_RELEASE_PATH
+        parseLsbRelease(FF_STR(FF_CUSTOM_LSB_RELEASE_PATH), os);
+        #endif
+    return;
+    #endif
+
+    if (detectBedrock(os))
+        return;
 
     // Refer: https://gist.github.com/natefoo/814c5bf936922dad97ff
 
@@ -323,14 +370,16 @@ void ffDetectOSImpl(FFOSResult* os)
 {
     detectOS(os);
 
-    #ifdef __linux__
-    if(ffStrbufIgnCaseEqualS(&os->id, "ubuntu"))
+    #if __linux__ || __GNU__
+    if(ffStrbufEqualS(&os->id, "ubuntu"))
         getUbuntuFlavour(os);
-    else if(ffStrbufIgnCaseEqualS(&os->id, "debian"))
+    else if(ffStrbufEqualS(&os->id, "debian"))
     {
         if (!detectDebianDerived(os))
             getDebianVersion(os);
     }
+    else if(ffStrbufEqualS(&os->id, "fedora"))
+        detectFedoraVariant(os);
     else if(ffStrbufEqualS(&os->id, "linuxmint"))
     {
         if (ffStrbufEqualS(&os->name, "LMDE"))
